/*
    Logic for portal form pages from HWZ International AG.

    authors: Stanislaw Koltschin
    
 */

var currentPageLanguage;
var currentPageDefaultLanguage = "de-DE";
var localizationStrings;

if (window.jQuery) {
    (function ($) {
        $(document).ready(function () {
            initLanguage();
            initForm();
            initEvents();
        })
    }(window.jQuery));
}

var initLanguage = function () {
    try {
        regexForLocale = /\/(\w\w\-\w\w)\//;
        match = window.location.pathname.match(regexForLocale);
        if (match && match.length > 0) {
            currentPageLanguage = match[1];
        } else {
            currentPageLanguage = currentPageDefaultLanguage;
            log.error("Page language cannot be parsed. Setting default language: "+currentPageDefaultLanguage)
        }
        
        localizationStrings = {
            "de-DE": {
                "please_select": "Bitte auswählen",
                "please_accept_privacy_and_terms":"Bitte akzeptieren Sie unsere <a href='https://www.hwzinternational.com/garantiebestimmungen'>Garantiebestimmungen</a> und <a href='https://www.hwzinternational.com/datenschutz-fuer-reklamationsabwicklung'>Datenschutzhinweise</a>",
                "detailed_complaint_description": "Detaillierte Reklamationsbeschreibung",
                "file_attachment_description": `Bitte senden Sie uns: <br />
                - 1 bis 2 Bilder in Nahaufnahme der Beanstandung sowie Bilder, des gesamten Raums. Generell gilt: Je mehr, desto besser!<br />
                - Foto oder Scan des Kaufbelegs<br />
                - Lieferschein (optional)<br />
                Es können maximal 30 MB übermittelt werden.
                `,
                "file_attachment_description_presales": `Bitte senden Sie uns: <br />
                - 1 bis 2 Bilder in Nahaufnahme der Beanstandung. Generell gilt: Je mehr, desto besser!<br />
                - Foto oder Scan des Kaufbelegs<br />
                - Lieferschein<br />
                Es können maximal 30 MB übermittelt werden.
                `,
                "orkg_ean_description": `Geben Sie hier die 13 stellige Produkt-EAN-Nummer an. 
                Sie finden die Produkt-EAN-Nummer entweder auf der Verpackung oder auf dem Kassenzettel. Oder fragen Sie bei Ihrem Händler nach.<br />
                <img src="~/images/ean-sample.png" />
                `,
                "orkg_chargennr_description": `Wenn bekannt, beben Sie hier die Chargen-Nr. der Ware an. 
                Sie finden die Chargen-Nr. direkt neben der EAN-Nummer auf der Verpackung des Produktes.`,
                "orkg_gegenstaende_description": "Mit der Wand verbundene Gegenstände bzw. Möbel wie Küchenzeilen oder Einbauschränke",
                "is_required_field":"ist ein Pflichtfeld."
            },
        "en-US": {
                "please_select": "Please select",
                "please_accept_privacy_and_terms":"Please accept our <a href='https://www.hwzinternational.com/garantiebestimmungen'>terms</a> and <a href='https://www.hwzinternational.com/datenschutz-fuer-reklamationsabwicklung'>privacy policy</a>.",
                "detailed_complaint_description": "Detailed complaint description",
                "file_attachment_description": `Please send us: <br />
                - 1 to 2 close-up pictures of the complaint and pictures of the entire room. In general: the more, the better!<br />
                - Photo or scan of proof of purchase<br />
                - Delivery note (optional)<br />
                A maximum of 30 MB can be transmitted.
                `,
                "file_attachment_description_presales": `Please send us: <br />
                - 1 to 2 close-up pictures of the complaint. In general: the more, the better!<br />
                - Photo or scan of proof of purchase<br />
                - Delivery note<br />
                A maximum of 30 MB can be transmitted.
                `,
                "orkg_ean_description": `Enter the 13-digit product EAN number here.
                You can find the product EAN number either on the packaging or on the receipt. Or ask your dealer.<br />
                <img src="~/images/ean-sample.png" />
                `,
                "orkg_chargennr_description": `If known, enter the batch number here. the goods.
                You will find the batch no. right next to the EAN number on the product packaging.` ,
                "orkg_gegenstaende_description": "Objects or furniture connected to the wall, such as kitchen units or built-in cupboards.",
                "is_required_field":"is a required field."
            },
            "fr-FR": {
                "please_select": "Veuillez sélectionner",
                "please_accept_privacy_and_terms" : "Veuillez accepter nos <a href='https://www.hwzinternational.com/garantiebestimmungen'>termes</a> et <a href='https://www.hwzinternational.com/datenschutz-fuer-reklamationsabwicklung'>politique de confidentialité</a>.",
                "detailed_complaint_description": "Description détaillée de la plainte",
                "file_attachment_description": `Veuillez nous envoyer : <br />
                - 1 à 2 photos en gros plan de la plainte et des photos de toute la pièce. En général : plus il y en a, mieux c'est !<br />
                - Photo ou scan de la preuve d'achat<br />
                - Bulletin de livraison (facultatif)<br />
                Un maximum de 30 MB peut être transmis.
                `,
                "file_attachment_description_presales": `Veuillez nous envoyer <br />
                - 1 ou 2 photos en gros plan de la réclamation. En règle générale, plus il y en a, mieux c'est !<br />
                - Photo ou scan de la preuve d'achat<br />
                - Bon de livraison<br />
                Un maximum de 30 MB peut être transmis.
                `,
                "orkg_ean_description": `Entrez ici le numéro EAN du produit à 13 chiffres.
                Vous pouvez trouver le numéro EAN du produit soit sur l'emballage, soit sur le ticket de caisse. Ou demandez à votre revendeur.<br />
                <img src="~/images/ean-sample.png" />
                `,
                "orkg_chargennr_description": `Si connu, entrez le numéro de lot ici. les biens. 
                Vous trouverez le numéro de lot. juste à côté du numéro EAN sur l'emballage du produit.`,
                "orkg_gegenstaende_description": "Objets ou meubles reliés au mur, tels que les éléments de cuisine ou les armoires encastrées.",
                "is_required_field":"est obligatoire."
            }
        };
        
        if ( ! localizationStrings.hasOwnProperty(currentPageLanguage) ) {
            if( localizationStrings.hasOwnProperty(currentPageDefaultLanguage) ) {
                console.error("Translations data for language '"+currentPageLanguage+"' missing - using default language: " + defaultLang);
                lang = defaultLang;
            } else {
                console.error("Translations data for language '"+currentPageLanguage+"' and default language '" + currentPageDefaultLanguage+"' missing.");
            }
        }
    } catch (error) {console.error(error);}
}

var initForm = function () {
    fieldCaseOrigin_SetValueAndHide();
    MakeRequired("orkg_consentgiven");
    sectionLogicSelbstInstalliert_SetVisibilityAndRequirement();
    sectionLogicEnvironmentInfo_SetVisibility();
    subsectionLogicEnvironmentInfo_EstrichPlatten_SetVisibilityAndRequirement();
    subsectionLogicEnvironmentInfo_Vinylbodenbefestigung_SetVisibilityAndRequirement();
    subsectionEnvironmentInfo_Unterlagsmatte_SetVisibilityAndRequirement();
    feststehendeEinbauten_SetVisibilityAndRequirement();
    transportSchadenLogic_SetVisibilityAndRequirement();
    initLocalization();
    uncheckBooleanRadioInputs();
}

var initEvents = function () {
    try {
    $("#orkg_reklamationsgrundcode").change(function() {
        transportSchadenLogic_SetVisibilityAndRequirement();
    });
    $("#orkg_selbstinstalliert").change(function() {
        sectionLogicSelbstInstalliert_SetVisibilityAndRequirement();
    });
    
    $("#orkg_portalproducttype").change(function() {
        sectionLogicEnvironmentInfo_SetVisibility();});

    $("#orkg_wurdensockelleistenhohlfachschienenmontiert").change(function() {
        subsectionLogicEnvironmentInfo_Vinylbodenbefestigung_SetVisibilityAndRequirement();
    });
        
    $("#orkg_estrichplatten").change(function() {
        subsectionLogicEnvironmentInfo_EstrichPlatten_SetVisibilityAndRequirement();
    });

    $("#orkg_unterlagsmatte").change(function() {
        subsectionEnvironmentInfo_Unterlagsmatte_SetVisibilityAndRequirement();
    });

    $("#orkg_feststehende_einbauten").change(function() {
        feststehendeEinbauten_SetVisibilityAndRequirement();
    });

    } catch (error) {console.error(error);}
}

var initLocalization = function () {
    try {
        $("option[value='']").attr("label",text("please_select"));
        $(".msos-input").attr("placeholder",text("please_select"));
        $("input.msos-input").ready(function() { //deferred localization is needed, because some Microsoft logic overwrites the label otherwise.
            $("input.msos-input").attr("placeholder",text("please_select"));});
        
        $("#orkg_consentgiven_label").html(text("please_accept_privacy_and_terms"));
        $("#orkg_description").attr("placeholder",text("detailed_complaint_description"));
        $("#orkg_reklamationsgrundcode>option[value='']").attr("label",text("please_select"));

        $("#orkg_ean").closest("div").prepend("<div>"+ text("orkg_ean_description") + "</div>");
        $("#orkg_chargennr").closest("div").prepend("<div>" + text("orkg_chargennr_description") + "</div>");
        $("#orkg_gegenstaende").closest("div").prepend("<div>" + text("orkg_gegenstaende_description") + "</div>");
        
        
        let url = window.location.href;
        if (url.includes("presale")) {
            $("#AttachFileLabel").html(text("file_attachment_description_presales"));
        } else {
            $("#AttachFileLabel").html(text("file_attachment_description"));
        }
        
    } catch (error) {console.error(error);}
}

var transportSchadenLogic_SetVisibilityAndRequirement = function() {
    try {
        if (isReklamaktionstypTransportschaden()) {
            MakeSectionNotRequired("section_Installer"); // Installateur
            hideSection("section_Installer");
            MakeSectionNotRequired("section_Problemdetails"); // Problemdetails
            hideSection("section_Problemdetails");
            sectionLogicEnvironmentInfo_SetVisibility();
        } else {
            showAndRequireFields([
                "orkg_selbstinstalliert",
                "orkg_datuminstallation",
                "orkg_fachbetriebstypderinstallationverlegung",
                "orkg_installateurname",
                "orkg_installateurstrasse",
                "orkg_installateurhausnummer",
                "orkg_installerpostalcode",
                "orkg_installercity",
                "orkg_installateurtelefon",
                "orkg_installateuremail"
            ]);
            showAndRequireFields([
                "orkg_datumproblem",
                "orkg_betroffeneraeumecode",
                "orkg_fachbetriebstypderinstallationverlegung"
            ]);
            showSection("section_Installer");// Installateur
            showSection("section_Problemdetails");// Problemdetails
            sectionLogicEnvironmentInfo_SetVisibility();
        }
} catch (error) {console.error(error);}
}

var sectionLogicSelbstInstalliert_SetVisibilityAndRequirement = function () {
    if($("input:checked", "#orkg_selbstinstalliert").length) {
        
        let installateurFelder = ["orkg_fachbetriebstypderinstallationverlegung"
        ,"orkg_installateuremail"
        ,"orkg_installateurname"
        ,"orkg_installateurhausnummer"
        ,"orkg_installateurstrasse"
        ,"orkg_installerpostalcode"
        ,"orkg_installercity"
        ,"orkg_installateurtelefon"]

        if ($("input:checked", "#orkg_selbstinstalliert").val() == true) {
            hideAndUnRequireFields(installateurFelder);
        } else {
            showAndRequireFields(installateurFelder);
        }
    }
}

var sectionLogicEnvironmentInfo_SetVisibility = function () {
    try {
        let typBoden = 159370001;
        let typWand = 159370002;

        if ( ! isReklamaktionstypTransportschaden()) { 
            if (typBoden == Number.parseInt($("#orkg_portalproducttype").val())) {
                showSection("section_Umgebungsinformation_Boden");
                hideSection("section_Umgebungsinformation_Wand");
                MakeSectionNotRequired("section_Umgebungsinformation_Wand");
                showAndRequireFields_SectionBoden();
            } else if (typWand == Number.parseInt($("#orkg_portalproducttype").val())) {
                showSection("section_Umgebungsinformation_Wand");
                hideSection("section_Umgebungsinformation_Boden");
                MakeSectionNotRequired("section_Umgebungsinformation_Boden");
                showAndRequireFields_SectionWand();
            } else {
                hideAndUnrequireEnvironmentInfo();
            }
        } else {
            hideAndUnrequireEnvironmentInfo();
        }
    } catch (error) {console.error(error);}
}

var text = function (translationKey) {
    try {
        /* Wrapper funtion for strings which have to be translated. Could be replaced by jQuery i18n library */
        //return localizationStrings[currentPageLanguage][translationKey];

        let defaultLang = currentPageDefaultLanguage;

        let lang = currentPageLanguage;

        let translation = localizationStrings[lang][translationKey]

        if (!(translation)) {
            translation = localizationStrings[defaultLang][translationKey]
            if (!!(translation)) {
                console.error("Translation for language " + lang + " with following key missing: "+ translationKey);
            } else {
                console.error("Translation for default language "+ defaultLang + " and current language "+ lang + " with following key missing: "+ translationKey)
                translation = translationKey.replace("_", " ");
            }
        }
        return translation;
    } catch (error) {
        console.error(error);
        return translationKey.replace("_", " ");
    }
}

var showAndRequireFields = function (fieldArray) {
    for (const fieldname of fieldArray) {
        ShowField(fieldname);
        MakeRequired(fieldname);
    }
}

var hideAndUnRequireFields = function (fieldArray) {
    for (const fieldname of fieldArray) {
        HideField(fieldname);
        MakeNotRequired(fieldname);
    }
}

var showAndRequireField = function (fieldname) {
    ShowField(fieldname);
    MakeRequired(fieldname);
}

var hideAndUnRequireField = function (fieldname) {
    HideField(fieldname);
    MakeNotRequired(fieldname);
}

var ShowField = function (fieldname) {
    try {$("#" + fieldname).closest("tr").find("div.control, div.info, td").show();}
    catch (error) {console.error(error);}
} 
var HideField = function (fieldname) {
    try {$("#" + fieldname).closest("tr").find("div.control, div.info, td").hide();}
    catch (error) {console.error(error);}
} 

//Make mandatory field
var MakeRequired = function (fieldName) {
    try {
        if ($("#" + fieldName).length) { // checks if element exists
            newValidatorId = "RequiredFieldValidator" + fieldName;

            for (i = 0; i < Page_Validators.length; i++) {
                if(Page_Validators[i].id == newValidatorId) {
                    console.log("Validator '"+newValidatorId+"' already exists");
                    return;
                }
            }
            
            $("#" + fieldName).prop('required', true);
            $("#" + fieldName).closest(".control").prev().addClass("required");

            // Create new validator
            var Requiredvalidator = document.createElement('span');
            Requiredvalidator.style.display = "none";
            Requiredvalidator.id = newValidatorId;
            Requiredvalidator.controltovalidate = fieldName;
            Requiredvalidator.errormessage = "<a href='#" + fieldName + "_label'>" + $("#" + fieldName + "_label").html() + " " + text("is_required_field") + "</a>";
            Requiredvalidator.initialvalue = "";
            Requiredvalidator.evaluationfunction = function () {
                let field = $("#" + fieldName);
                var value = field.fieldValue();
                if(field.hasClass("boolean-radio")) {
                    if ($("#" + fieldName + "_0").is(':checked')
                        || $("#" + fieldName + "_1").is(':checked')
                        ) {
                        return true;
                    } else {
                        return false;
                    }
                } else {
                    if (value == null || value == "") {
                        return false;
                    } else {
                        return true;
                    }
                }
            };

            // Add the new validator to the page validators array:
            Page_Validators.push(Requiredvalidator);
        }
    } catch (error) {console.error(error);}
}
//Make UnMandatory
var MakeNotRequired = function (fieldName) {
    try {
        if ($("#" + fieldName) != undefined) {
            $("#" + fieldName).closest(".control").prev().removeClass("required");
            $("#" + fieldName).prop('required', false);

            for (i = 0; i < Page_Validators.length; i++) {
                if (Page_Validators[i].controltovalidate == fieldName ) {
                    Page_Validators.splice(i,1);
                }
            }
        }
    } catch (error) {console.error(error);}
}

var MakeSectionNotRequired = function (sectionName) {
    try {
        if ($("table[data-name='" + sectionName + "']") != undefined) {
            $("table[data-name='" + sectionName + "'] .control").prev().removeClass("required");
            $("table[data-name='" + sectionName + "'] .control").prop('required', false);

            let controls1 = $("table[data-name='" + sectionName + "'] .control > input");
            let controlsSelect = $("table[data-name='" + sectionName + "'] .control > select");
            let controlsRadio = $("table[data-name='" + sectionName + "'] .control > span.boolean-radio");
            let controls = controls1.add(controlsSelect).add(controlsRadio);
            let controlFieldNameIds = []
            for (const control of controls) {
                if (control.id) {
                    controlFieldNameIds.push(control.id)
                } 
            }
            for (i = 0; i < Page_Validators.length; i++) {
                let fieldName = Page_Validators[i].controltovalidate; // id pattern is "RequiredFieldValidator" + fieldName, so remove the first to get the field name.
                let validatorId = Page_Validators[i].id;
                let validatorType = validatorId.replace(fieldName,"");
                let validatorType_RequiredField = "RequiredFieldValidator";
                if (fieldName && validatorType == validatorType_RequiredField  && controlFieldNameIds.includes(fieldName)) {
                    Page_Validators.splice(i--,1);
                }
            }
        }
    } catch (error) {console.error(error);}
}

function hideAndUnrequireEnvironmentInfo() {
    hideSection("section_Umgebungsinformation_Wand");
    hideSection("section_Umgebungsinformation_Boden");
    MakeSectionNotRequired("section_Umgebungsinformation_Wand");
    MakeSectionNotRequired("section_Umgebungsinformation_Boden");
}

function showSection(section) {
    $("table[data-name='"+section+"']").parent().show();
}
function hideSection(section) {
    $("table[data-name='"+section+"']").parent().hide();
}

function isReklamaktionstypTransportschaden() {
    let typTransportschaden = 200000017;
    return typTransportschaden == Number.parseInt($("#orkg_reklamationsgrundcode").val());
}

function uncheckBooleanRadioInputs() {
    // unchecks boolean radio inputs to allow initial selection of yes or no and thus allow a required field check.
    let checks = $(".boolean-radio > input");
    checks.removeAttr("checked");
}

function showAndRequireFields_SectionWand() {
    showAndRequireFields([
        "orkg_raumfeuchtigkeit",
        "orkg_raumtemperaturmin",
        "orkg_raumtemperaturmax",
        "orkg_materialakklimatisiert",
        "orkg_materialakklimatisiertstunden",
        "orkg_beschaffenheitwand",
        "orkg_beschaffenheitwandsonstige",
        "orkg_wandbefestigung",
        "orkg_wandbefestigungsonstige"
    ]);
}

function showAndRequireFields_SectionBoden() {
    showAndRequireFields([
        "orkg_sonneneinstrahlung",
        "orkg_roomsizem2",
        "orkg_wurdenraumezusammenhangendverlegt",
        "orkg_wievielmisstdiedielenbahncm",
        "orkg_welchewandabstandesindvorhandencm",
        "orkg_wurdensockelleistenhohlfachschienenmontiert",
        "orkg_wurdendieseaufdemvinylbodenbefestigt",
        "orkg_vinylbodenbelagschwimmendverlegtoderfixiert",
        "orkg_bodenakklimatisiert",
        "orkg_heizungsartcode",
        "orkg_feststehende_einbauten",
        "orkg_beschaffenheitcode",
        "orkg_estrichplatten",
        "orkg_unebenheiten",
        "orkg_unterlagsmatte",
        "orkg_verarbeitungderklickverbindung",
        "orkg_nachgeklopft"]
    );
}

function fieldCaseOrigin_SetValueAndHide() {
    try {
        HideField("orkg_caseorigindetails");

        let url = window.location.href;

        if (url.includes("customer")) {
            $("#orkg_caseorigindetails").val("Reklamationsformular Kunde " + currentPageLanguage);
        } else if (url.includes("merchant") && !url.includes("merchantformpresale")) {
            $("#orkg_caseorigindetails").val("Reklamationsformular Händler verkaufte Ware " + currentPageLanguage);
        } else if(url.includes("merchantformpresale")) {
            $("#orkg_caseorigindetails").val("Reklamationsformular Händler unverkaufte Ware " + currentPageLanguage);
        } else {
            console.error("URL / form type not recognized, cannot set case orgin details field.")
        }
    } catch (error) {console.error(error);}
}

function feststehendeEinbauten_SetVisibilityAndRequirement() {
    if ($("input:checked", "#orkg_feststehende_einbauten").val() == false) {
        hideAndUnRequireField("orkg_feststehende_einbauten_detail");
    } else if ($("#orkg_feststehende_einbauten").is(":visible")) {
        showAndRequireField("orkg_feststehende_einbauten_detail");
    }
}

function subsectionEnvironmentInfo_Unterlagsmatte_SetVisibilityAndRequirement() {
    if ($("input:checked", "#orkg_unterlagsmatte").val() == false) {
        hideAndUnRequireField("orkg_unterlagsmattedicke");
        hideAndUnRequireField("orkg_unterlagsmattedruckfestigkeit");
        hideAndUnRequireField("orkg_unterlagsmattemarke");
    } else if ($("#orkg_unterlagsmatte").is(":visible")) {
        showAndRequireField("orkg_unterlagsmattedicke");
        showAndRequireField("orkg_unterlagsmattedruckfestigkeit");
        showAndRequireField("orkg_unterlagsmattemarke");
    }
}

function subsectionLogicEnvironmentInfo_EstrichPlatten_SetVisibilityAndRequirement() {
    if ($("input:checked", "#orkg_estrichplatten").val() == false) {
        hideAndUnRequireField("orkg_estrichplattendefinitioncode");
        hideAndUnRequireField("orkg_estrichplattenverarbeitungcode");
    } else if ($("#orkg_estrichplatten").is(":visible")) {
        showAndRequireField("orkg_estrichplattendefinitioncode");
        showAndRequireField("orkg_estrichplattenverarbeitungcode");
    }
}

function subsectionLogicEnvironmentInfo_Vinylbodenbefestigung_SetVisibilityAndRequirement() {
    if ($("input:checked", "#orkg_wurdensockelleistenhohlfachschienenmontiert").val() == false) {
        hideAndUnRequireField("orkg_wurdendieseaufdemvinylbodenbefestigt");
    } else if ($("#orkg_unterlagsmatte").is(":visible")) {
        showAndRequireField("orkg_wurdendieseaufdemvinylbodenbefestigt");
    }
}